@@ -1,7 +1,7 @@
 /**
  * DimpBase.js - Javascript used in the base DIMP page.
  *
- * $Horde: dimp/js/src/DimpBase.js,v 1.1.2.119 2010/09/27 18:14:34 slusarz Exp $
+ * $Horde: dimp/js/src/DimpBase.js,v 1.1.2.120 2012/02/06 05:50:45 slusarz Exp $
  *
  * Copyright 2005-2009 The Horde Project (http://www.horde.org/)
  *
@@ -1559,7 +1559,7 @@ var DimpBase = {
             }.bindAsEventListener(this)));
         }
 
-        li.insert(div).insert(new Element('A', { id: fid + '_label', title: ob.l }).insert(ob.l));
+        li.insert(div).insert(new Element('A', { id: fid + '_label', title: ob.l }).insert(ob.l ? ob.l.escapeHTML() : ob.l));
 
         // Now walk through the parent <ul> to find the right place to
         // insert the new folder.
